# Changelog

## [0.3.0] - 2023/05/09

### Added

- Standalone script for repository distribution

### Changed

- Remove `build` command
- Remove `sync` command

## [0.2.0] - 2022/09/15

### Added

- Cosmetic logging submodule
- New `build` command
- New `sync` command

### Changed

- Refactor Bazel functions to submodule
- Remove dependency on colorama

## [0.1.0] - 2022/08/18

First release of the project.
